@@ -22,4 +22,9 @@ GDAL_DRIVERS_NAME = {
     'GeoJSON': 'GeoJSON'
 }
 
-PRJ_WGS84='GEOGCS["WGS 84",DATUM["WGS_1984",SPHEROID["WGS 84",6378137,298.257223563,AUTHORITY["EPSG","7030"]],AUTHORITY["EPSG","6326"]],PRIMEM["Greenwich",0,AUTHORITY["EPSG","8901"]],UNIT["degree",0.01745329251994328,AUTHORITY["EPSG","9122"]],AUTHORITY["EPSG","4326"]]'
\ No newline at end of file
+GEOMETRYCOLLECTION_PREFIX = 'GEOMETRYCOLLECTION'
+GEOM_COLLECTION_LEN = len(GEOMETRYCOLLECTION_PREFIX)
+
+PRJ_WGS84='GEOGCS["WGS 84",DATUM["WGS_1984",SPHEROID["WGS 84",6378137,298.257223563,AUTHORITY["EPSG","7030"]],AUTHORITY["EPSG","6326"]],PRIMEM["Greenwich",0,AUTHORITY["EPSG","8901"]],UNIT["degree",0.01745329251994328,AUTHORITY["EPSG","9122"]],AUTHORITY["EPSG","4326"]]'
+
+NoneType = type(None)
